pub struct MigrateMiSyncCompleteCommandOutput {
pub errors: Vec<ReportableException>,
}Expand description
Output for command that completes online migration for an Azure SQL Database Managed Instance.
Fields
errors: Vec<ReportableException>List of errors that happened during the command execution
Implementations