pub struct MigrateSqlServerSqlMiSyncTaskOutputDatabaseLevel {
pub migrate_sql_server_sql_mi_sync_task_output: MigrateSqlServerSqlMiSyncTaskOutput,
pub source_database_name: Option<String>,
pub migration_state: Option<DatabaseMigrationState>,
pub started_on: Option<OffsetDateTime>,
pub ended_on: Option<OffsetDateTime>,
pub full_backup_set_info: Option<BackupSetInfo>,
pub last_restored_backup_set_info: Option<BackupSetInfo>,
pub active_backup_sets: Vec<BackupSetInfo>,
pub container_name: Option<String>,
pub error_prefix: Option<String>,
pub is_full_backup_restored: Option<bool>,
pub exceptions_and_warnings: Vec<ReportableException>,
}Fields
migrate_sql_server_sql_mi_sync_task_output: MigrateSqlServerSqlMiSyncTaskOutputsource_database_name: Option<String>Name of the database
migration_state: Option<DatabaseMigrationState>Database level migration state.
started_on: Option<OffsetDateTime>Database migration start time
ended_on: Option<OffsetDateTime>Database migration end time
full_backup_set_info: Option<BackupSetInfo>Information of backup set
last_restored_backup_set_info: Option<BackupSetInfo>Information of backup set
active_backup_sets: Vec<BackupSetInfo>Backup sets that are currently active (Either being uploaded or getting restored)
container_name: Option<String>Name of container created in the Azure Storage account where backups are copied to
error_prefix: Option<String>prefix string to use for querying errors for this database
is_full_backup_restored: Option<bool>Whether full backup has been applied to the target database or not
exceptions_and_warnings: Vec<ReportableException>Migration exceptions and warnings
Implementations
Sourceimpl MigrateSqlServerSqlMiSyncTaskOutputDatabaseLevel
impl MigrateSqlServerSqlMiSyncTaskOutputDatabaseLevel
pub fn new( migrate_sql_server_sql_mi_sync_task_output: MigrateSqlServerSqlMiSyncTaskOutput, ) -> Self