pub struct ProjectFileProperties {
pub extension: Option<String>,
pub file_path: Option<String>,
pub last_modified: Option<OffsetDateTime>,
pub media_type: Option<String>,
pub size: Option<i64>,
}Expand description
Base class for file properties.
Fields
extension: Option<String>Optional File extension. If submitted it should not have a leading period and must match the extension from filePath.
file_path: Option<String>Relative path of this file resource. This property can be set when creating or updating the file resource.
last_modified: Option<OffsetDateTime>Modification DateTime.
media_type: Option<String>File content type. This property can be modified to reflect the file content type.
size: Option<i64>File size.
Implementations