pub struct ConnectToSourceMySqlTaskInput {
pub source_connection_info: MySqlConnectionInfo,
pub target_platform: Option<MySqlTargetPlatform>,
pub check_permissions_group: Option<ServerLevelPermissionsGroup>,
pub is_offline_migration: Option<bool>,
}Expand description
Input for the task that validates MySQL database connection
Fields
source_connection_info: MySqlConnectionInfoInformation for connecting to MySQL server
target_platform: Option<MySqlTargetPlatform>An enumeration of possible target types when migrating from MySQL
check_permissions_group: Option<ServerLevelPermissionsGroup>Permission group for validations. These groups will run a set of permissions for validating user activity. Select the permission group for the activity that you are performing.
is_offline_migration: Option<bool>Flag for whether or not the migration is offline
Implementations
Sourceimpl ConnectToSourceMySqlTaskInput
impl ConnectToSourceMySqlTaskInput
pub fn new(source_connection_info: MySqlConnectionInfo) -> Self