pub struct ConnectToTargetSqlMiSyncTaskInput {
pub target_connection_info: MiSqlConnectionInfo,
pub azure_app: AzureActiveDirectoryApp,
}Expand description
Input for the task that validates connection to Azure SQL Database Managed Instance online scenario.
Fields
target_connection_info: MiSqlConnectionInfoProperties required to create a connection to Azure SQL database Managed instance
azure_app: AzureActiveDirectoryAppAzure Active Directory Application
Implementations
Sourceimpl ConnectToTargetSqlMiSyncTaskInput
impl ConnectToTargetSqlMiSyncTaskInput
pub fn new( target_connection_info: MiSqlConnectionInfo, azure_app: AzureActiveDirectoryApp, ) -> Self